@@ -3,6 +3,8 @@
 pub use error_chain::bail;
 use error_chain::error_chain;
 
+// TODO fix the integration errors
+
 // The `error_chain` setup for the whole crate
 // All systems use these errors, except for GraphQL resolvers, because they have to return a particular kind of error
 error_chain! {
@@ -33,8 +35,8 @@ error_chain! {
 
         /// The subscriptions server failed to publish data it was asked to. This error is usually caused by an authentication failure.
         SubscriptionDataPublishFailed {
-            description("subscriptions server failed to publish data internally")
-            display("subscriptions server failed to publish data internally, this is most likely due to an authentication failure")
+            description("failed to publish data to the subscriptions server")
+            display("failed to publish data to the subscriptions server, this is most likely due to an authentication failure")
         }
 
         /// An invalid indicator string was used when trying to convert a timestring into a datetime.
@@ -66,6 +68,22 @@ error_chain! {
             description("you tried to create a subscriptions server without configuring it in the options")
             display("you tried to create a subscriptions server without configuring it in the options")
         }
+
+        /// There was an attempt to initialize the GraphiQL playground in a production environment.
+        AttemptedPlaygroundInProduction {
+            description("you tried to initialize the GraphQL playground in production, which is not supported due to authentication issues")
+            display("you tried to initialize the GraphQL playground in production, which is not supported due to authentication issues")
+        }
+
+        /// There was an error in one of the integrations.
+        IntegrationError(message: String, integration_name: String) {
+            description("an error occurred in one of Diana's integration libraries")
+            display(
+                "the following error occurred in the '{integration_name}' integration library: {message}",
+                integration_name=integration_name,
+                message=message
+            )
+        }
     }
     // We work with many external libraries, all of which have their own errors
     foreign_links {
@@ -77,7 +95,7 @@ error_chain! {
     }
 }
 
-/// A wrapper around [async_graphql::Result<T>](async_graphql::Result).
+/// A wrapper around [`async_graphql::Result<T>`](async_graphql::Result).
 /// You should use this as the return type for any of your own schemas that might return errors.
 /// # Example
 /// ```rust
@@ -89,7 +107,7 @@ error_chain! {
 /// }
 /// ```
 pub type GQLResult<T> = async_graphql::Result<T>;
-/// A wrapper around [async_graphql::Error].
+/// A wrapper around [`async_graphql::Error`].
 /// If any of your schemas need to explicitly create an error that only exists in them (and you're not using something like [mod@error_chain]),
 /// you should use this.
 /// # Example
